# nowcasting-dataloader
PyTorch Dataloader for working with multi-modal data for nowcasting applications.  In particular, this code loads the pre-prepared batches saved to disk by [`nowcasting_dataset`](https://github.com/openclimatefix/nowcasting_dataset).  This code also computes some optional, additional input features.
